==> oil-0.20.0.tar.gz: _devbuild/gen/help_meta.py <==
TOPICS = {'ARGV': 'special-var',
 'BASHOPTS': 'special-var',
 'BASHPID': 'special-var',
 'BASH_REMATCH': 'special-var',
 'Better-Syntax': 'builtin-func',
 'Bool': 'packle',
 'Bytes': 'packle',
 'CDPATH': 'special-var',
 'COMPREPLY': 'special-var',
 'COMP_ARGV': 'special-var',
 'COMP_CWORD': 'special-var',
 'COMP_LINE': 'special-var',
 'COMP_POINT': 'special-var',
 'COMP_WORDS': 'special-var',
 'Dict': 'packle',
 'ENV': 'special-var',
 'EUID': 'special-var',
 'Float': 'packle',
 'GLOBIGNORE': 'special-var',
 'HISTFILE': 'special-var',
 'HOME': 'special-var',
 'IFS': 'special-var',
 'Int': 'packle',
 'LANG': 'special-var',
 'LINENO': 'special-var',
 'List': 'packle',
 'Null': 'packle',
 'OILS_GC_ON_EXIT': 'special-var',
 'OILS_GC_STATS': 'special-var',
 'OILS_GC_STATS_FD': 'special-var',
 'OILS_GC_THRESHOLD': 'special-var',
 'OILS_VERSION': 'special-var',
 'OLDPWD': 'special-var',
 'OPTARG': 'special-var',
 'OPTERR': 'special-var',
 'OPTIND': 'special-var',
 'PATH': 'special-var',
 'PIPESTATUS': 'special-var',
 'PPID': 'special-var',
 'PS1': 'plugin',
 'PS2': 'plugin',
 'PS3': 'plugin',
 'PS4': 'plugin',
 'PWD': 'special-var',
 'RANDOM': 'special-var',
 'REPLY': 'special-var',
 'SECONDS': 'special-var',
 'SHELLOPTS': 'special-var',
 'SHX_indent': 'special-var',
 'SHX_pid_str': 'special-var',
 'SHX_punct': 'special-var',
 'UID': 'special-var',
 'Unicode': 'packle',
 'YSH_HISTFILE': 'special-var',
 '_end()': 'builtin-func',
 '_error': 'special-var',
 '_group()': 'builtin-func',
 '_pipeline_status': 'special-var',
 '_process_sub_status': 'special-var',
 '_reply': 'special-var',
 '_start()': 'builtin-func',
 '_status': 'special-var',
 '_this_dir': 'special-var',
 'abs()': 'builtin-func',
 'accum()': 'type-method',
 'alias': 'builtin-cmd',
 'all()': 'builtin-func',
 'ampersand': 'cmd-lang',
 'and': 'cmd-lang',
 'any()': 'builtin-func',
 'append': 'builtin-cmd',
 'append()': 'type-method',
 'arith-context': 'mini-lang',
 'arith-sub': 'word-lang',
 'b-prefix': 'j8',
 'bang': 'cmd-lang',
 'block-arg': 'cmd-lang',
 'block-literal': 'expr-lang',
 'bool()': 'builtin-func',
 'bool-expr': 'mini-lang',
 'bool-infix': 'mini-lang',
 'bool-literal': 'expr-lang',
 'bool-other': 'mini-lang',
 'bool-path': 'mini-lang',
 'bool-str': 'mini-lang',
 'boolstatus': 'builtin-cmd',
 'braces': 'mini-lang',
 'break': 'cmd-lang',
 'builtin': 'builtin-cmd',
 'call': 'cmd-lang',
 'captureStdout()': 'type-method',
 'case': 'cmd-lang',
 'cat-em': 'front-end',
 'cd': 'builtin-cmd',
 'char-escapes': 'mini-lang',
 'chr()': 'builtin-func',
 'class-literal': 'expr-lang',
 'colon': 'cmd-lang',
 'column-attrs': 'j8',
 'column-types': 'j8',
 'com-sub': 'word-lang',
 'command': 'builtin-cmd',
 'command_sub_errexit': 'option',
 'comment': 'front-end',
 'compadjust': 'builtin-cmd',
 'compexport': 'builtin-cmd',
 'compgen': 'builtin-cmd',
 'complete': 'builtin-cmd',
 'compopt': 'builtin-cmd',
 'concat': 'expr-lang',
 'config': 'front-end',
 'const': 'cmd-lang',
 'continue': 'cmd-lang',
 'copy_env': 'option',
 'dashglob': 'option',
 'dbracket': 'mini-lang',
 'declare': 'osh-assign',
 'dict()': 'builtin-func',
 'dict-literal': 'expr-lang',
 'dirs': 'builtin-cmd',
 'doc-comment': 'front-end',
 'dparen': 'cmd-lang',
 'echo': 'builtin-cmd',
 'enable': 'builtin-cmd',
 'end()': 'type-method',
 'endsWith()': 'type-method',
 'equal': 'cmd-lang',
 'erase()': 'type-method',
 'error': 'builtin-cmd',
 'eval': 'builtin-cmd',
 'eval()': 'type-method',
 'exec': 'builtin-cmd',
 'exit': 'cmd-lang',
 'exit-codes': 'front-end',
 'export': 'osh-assign',
 'expr-lit': 'expr-lang',
 'expr-splice': 'word-lang',
 'expr-sub': 'word-lang',
 'extend()': 'type-method',
 'extglob': 'mini-lang',
 'false': 'cmd-lang',
 'fat-arrow': 'expr-lang',
 'fg': 'builtin-cmd',
 'find()': 'type-method',
 'float()': 'builtin-func',
 'for': 'cmd-lang',
 'for-expr-sh': 'cmd-lang',
 'fork': 'builtin-cmd',
 'forkwait': 'builtin-cmd',
 'func-call': 'expr-lang',
 'func-def': 'cmd-lang',
 'get()': 'type-method',
 'getopts': 'builtin-cmd',
 'glob()': 'type-method',
 'glob-pat': 'mini-lang',
 'group()': 'type-method',
 'hash': 'builtin-cmd',
 'help': None,
 'here-doc': 'cmd-lang',
 'history': 'builtin-cmd',
 'histsub': 'mini-lang',
 'if': 'cmd-lang',
 'inc()': 'type-method',
 'indexOf()': 'type-method',
 'insert()': 'type-method',
 'int()': 'builtin-func',
 'int-literal': 'expr-lang',
 'is-main': 'builtin-cmd',
 'j8-escape': 'j8',
 'j8-str': 'word-lang',
 'jobs': 'builtin-cmd',
 'join()': 'builtin-func',
 'json': 'builtin-cmd',
 'json-decode-err': 'errors',
 'json-encode-err': 'errors',
 'json-escape': 'j8',
 'json-string': 'j8',
 'json8': 'builtin-cmd',
 'json8-comment': 'j8',
 'json8-decode-err': 'errors',
 'json8-dict': 'j8',
 'json8-encode-err': 'errors',
 'json8-list': 'j8',
 'json8-num': 'j8',
 'json8-str': 'j8',
 'keys()': 'type-method',
 'kill': 'builtin-cmd',
 'lazy-expr-arg': 'cmd-lang',
 'leftMatch()': 'type-method',
 'len()': 'builtin-func',
 'line-continuation': 'front-end',
 'list()': 'builtin-func',
 'list-literal': 'expr-lang',
 'local': 'osh-assign',
 'lower()': 'type-method',
 'mapfile': 'builtin-cmd',
 'match-ops': 'expr-lang',
 'max()': 'builtin-func',
 'maybe()': 'builtin-func',
 'min()': 'builtin-func',
 'module': 'builtin-cmd',
 'multi-str': 'word-lang',
 'multiline-command': 'front-end',
 'named-class': 'expr-lang',
 'no-prefix': 'j8',
 'nullglob': 'option',
 'oils-usage': None,
 'op-format': 'word-lang',
 'op-index': 'word-lang',
 'op-replace': 'word-lang',
 'op-slice': 'word-lang',
 'op-strip': 'word-lang',
 'op-test': 'word-lang',
 'or': 'cmd-lang',
 'ord()': 'builtin-func',
 'osh-chapters': None,
 'osh-usage': None,
 'packle-decode-err': 'errors',
 'packle-encode-err': 'errors',
 'parse_at': 'option',
 'parse_brace': 'option',
 'parse_equals': 'option',
 'parse_ignored': 'option',
 'parse_paren': 'option',
 'parse_triple_quote': 'option',
 'parse_ysh_string': 'option',
 'pipe': 'cmd-lang',
 'pop()': 'type-method',
 'popd': 'builtin-cmd',
 'pp': 'builtin-cmd',
 'printf': 'builtin-cmd',
 'proc-def': 'cmd-lang',
 'process_sub_fail': 'option',
 'promptVal()': 'type-method',
 'push-registers': 'builtin-cmd',
 'pushd': 'builtin-cmd',
 'pwd': 'builtin-cmd',
 'quotes': 'word-lang',
 'range': 'expr-lang',
 're-capture': 'expr-lang',
 're-compound': 'expr-lang',
 're-flags': 'expr-lang',
 're-literal': 'expr-lang',
 're-multiline': 'expr-lang',
 're-primitive': 'expr-lang',
 're-repeat': 'expr-lang',
 're-splice': 'expr-lang',
 'read': 'builtin-cmd',
 'readarray': 'builtin-cmd',
 'redir-desc': 'cmd-lang',
 'redir-file': 'cmd-lang',
 'regex': 'mini-lang',
 'remove()': 'type-method',
 'renderPrompt()': 'plugin',
 'repeat()': 'builtin-func',
 'replace()': 'type-method',
 'return': 'cmd-lang',
 'reverse()': 'type-method',
 'round()': 'builtin-func',
 'rune-literal': 'expr-lang',
 'runes()': 'builtin-func',
 'runproc': 'builtin-cmd',
 'search()': 'type-method',
 'semicolon': 'cmd-lang',
 'set': 'builtin-cmd',
 'setValue()': 'type-method',
 'setglobal': 'cmd-lang',
 'setvar': 'cmd-lang',
 'sh-append': 'osh-assign',
 'sh-arith': 'mini-lang',
 'sh-array': 'osh-assign',
 'sh-assign': 'osh-assign',
 'sh-assoc': 'osh-assign',
 'sh-bitwise': 'mini-lang',
 'sh-block': 'cmd-lang',
 'sh-func': 'cmd-lang',
 'sh-logical': 'mini-lang',
 'sh-numbers': 'mini-lang',
 'shSplit()': 'builtin-func',
 'shift': 'osh-assign',
 'shopt': 'builtin-cmd',
 'shvar': 'builtin-cmd',
 'shvar_get()': 'builtin-func',
 'sigpipe_status_ok': 'option',
 'simple-command': 'cmd-lang',
 'simple_word_eval': 'option',
 'source': 'builtin-cmd',
 'split()': 'builtin-func',
 'start()': 'type-method',
 'startsWith()': 'type-method',
 'startup': 'front-end',
 'str()': 'builtin-func',
 'str-literal': 'expr-lang',
 'strcmp()': 'builtin-func',
 'strftime()': 'type-method',
 'strict:all': 'option',
 'strict_control_flow': 'option',
 'strict_nameref': 'option',
 'strict_tilde': 'option',
 'strict_word_eval': 'option',
 'subshell': 'cmd-lang',
 'sum()': 'builtin-func',
 'surrogate-pair': 'j8',
 'test': 'builtin-cmd',
 'thin-arrow': 'expr-lang',
 'tilde-sub': 'word-lang',
 'time': 'cmd-lang',
 'time()': 'type-method',
 'times': 'builtin-cmd',
 'trap': 'builtin-cmd',
 'trim()': 'type-method',
 'trimLeft()': 'type-method',
 'trimPrefix()': 'type-method',
 'trimRight()': 'type-method',
 'trimSuffix()': 'type-method',
 'triple-quoted': 'expr-lang',
 'true': 'cmd-lang',
 'try': 'builtin-cmd',
 'type': 'builtin-cmd',
 'type()': 'builtin-func',
 'typed-arg': 'cmd-lang',
 'typeset': 'osh-assign',
 'u-prefix': 'j8',
 'umask': 'builtin-cmd',
 'unalias': 'builtin-cmd',
 'unset': 'osh-assign',
 'until': 'cmd-lang',
 'upper()': 'type-method',
 'use': 'builtin-cmd',
 'utf8-decode-err': 'errors',
 'utf8-encode-err': 'errors',
 'values()': 'type-method',
 'var': 'cmd-lang',
 'var-splice': 'word-lang',
 'var-sub': 'word-lang',
 'wait': 'builtin-cmd',
 'while': 'cmd-lang',
 'write': 'builtin-cmd',
 'ysh-arith': 'expr-lang',
 'ysh-bitwise': 'expr-lang',
 'ysh-case': 'cmd-lang',
 'ysh-cd': 'builtin-cmd',
 'ysh-chapters': None,
 'ysh-compare': 'expr-lang',
 'ysh-for': 'cmd-lang',
 'ysh-format': 'word-lang',
 'ysh-if': 'cmd-lang',
 'ysh-index': 'expr-lang',
 'ysh-logical': 'expr-lang',
 'ysh-printf': 'word-lang',
 'ysh-read': 'builtin-cmd',
 'ysh-return': 'cmd-lang',
 'ysh-shopt': 'builtin-cmd',
 'ysh-slice': 'expr-lang',
 'ysh-ternary': 'expr-lang',
 'ysh-usage': None,
 'ysh-while': 'cmd-lang',
 'ysh:all': 'option',
 'ysh:upgrade': 'option'}


from typing import Dict

def TopicMetadata():
  # type: () -> Dict[str, str]
  return TOPICS

==> oil-0.21.0.tar.gz: _devbuild/gen/help_meta.py <==
TOPICS = {'ARGV': 'special-var',
 'BASHOPTS': 'special-var',
 'BASHPID': 'special-var',
 'BASH_REMATCH': 'special-var',
 'Better-Syntax': 'builtin-func',
 'Bool': 'packle',
 'Bytes': 'packle',
 'CDPATH': 'special-var',
 'COMPREPLY': 'special-var',
 'COMP_ARGV': 'special-var',
 'COMP_CWORD': 'special-var',
 'COMP_LINE': 'special-var',
 'COMP_POINT': 'special-var',
 'COMP_WORDS': 'special-var',
 'DEBUG': 'plugin',
 'Dict': 'packle',
 'ENV': 'special-var',
 'ERR': 'plugin',
 'EUID': 'special-var',
 'EXIT': 'plugin',
 'Float': 'packle',
 'GLOBIGNORE': 'special-var',
 'HISTFILE': 'special-var',
 'HOME': 'special-var',
 'IFS': 'special-var',
 'Int': 'packle',
 'LANG': 'special-var',
 'LINENO': 'special-var',
 'List': 'packle',
 'Null': 'packle',
 'OILS_GC_ON_EXIT': 'special-var',
 'OILS_GC_STATS': 'special-var',
 'OILS_GC_STATS_FD': 'special-var',
 'OILS_GC_THRESHOLD': 'special-var',
 'OILS_VERSION': 'special-var',
 'OLDPWD': 'special-var',
 'OPTARG': 'special-var',
 'OPTERR': 'special-var',
 'OPTIND': 'special-var',
 'PATH': 'special-var',
 'PIPESTATUS': 'special-var',
 'PPID': 'special-var',
 'PS1': 'plugin',
 'PS2': 'plugin',
 'PS3': 'plugin',
 'PS4': 'plugin',
 'PWD': 'special-var',
 'RANDOM': 'special-var',
 'REPLY': 'special-var',
 'RETURN': 'plugin',
 'SECONDS': 'special-var',
 'SHELLOPTS': 'special-var',
 'SHX_indent': 'special-var',
 'SHX_pid_str': 'special-var',
 'SHX_punct': 'special-var',
 'UID': 'special-var',
 'Unicode': 'packle',
 'YSH_HISTFILE': 'special-var',
 '_end()': 'builtin-func',
 '_error': 'special-var',
 '_group()': 'builtin-func',
 '_pipeline_status': 'special-var',
 '_process_sub_status': 'special-var',
 '_reply': 'special-var',
 '_start()': 'builtin-func',
 '_status': 'special-var',
 '_this_dir': 'special-var',
 'abs()': 'builtin-func',
 'accum()': 'type-method',
 'alias': 'builtin-cmd',
 'all()': 'builtin-func',
 'ampersand': 'cmd-lang',
 'and': 'cmd-lang',
 'any()': 'builtin-func',
 'append': 'builtin-cmd',
 'append()': 'type-method',
 'arg': 'builtin-cmd',
 'arith-context': 'mini-lang',
 'arith-sub': 'word-lang',
 'b-prefix': 'j8',
 'bang': 'cmd-lang',
 'block-arg': 'cmd-lang',
 'block-literal': 'expr-lang',
 'bool()': 'builtin-func',
 'bool-expr': 'mini-lang',
 'bool-infix': 'mini-lang',
 'bool-literal': 'expr-lang',
 'bool-other': 'mini-lang',
 'bool-path': 'mini-lang',
 'bool-str': 'mini-lang',
 'boolstatus': 'builtin-cmd',
 'braces': 'mini-lang',
 'break': 'cmd-lang',
 'builtin': 'builtin-cmd',
 'call': 'cmd-lang',
 'captureStdout()': 'type-method',
 'case': 'cmd-lang',
 'cat-em': 'front-end',
 'cd': 'builtin-cmd',
 'char-escapes': 'mini-lang',
 'chr()': 'builtin-func',
 'class-literal': 'expr-lang',
 'colon': 'cmd-lang',
 'column-attrs': 'j8',
 'column-types': 'j8',
 'com-sub': 'word-lang',
 'command': 'builtin-cmd',
 'command_sub_errexit': 'option',
 'comment': 'front-end',
 'compadjust': 'builtin-cmd',
 'compexport': 'builtin-cmd',
 'compgen': 'builtin-cmd',
 'complete': 'builtin-cmd',
 'compopt': 'builtin-cmd',
 'concat': 'expr-lang',
 'config': 'front-end',
 'const': 'cmd-lang',
 'continue': 'cmd-lang',
 'copy_env': 'option',
 'ctx': 'builtin-cmd',
 'dashglob': 'option',
 'dbracket': 'mini-lang',
 'declare': 'osh-assign',
 'dict()': 'builtin-func',
 'dict-literal': 'expr-lang',
 'dirs': 'builtin-cmd',
 'doc-comment': 'front-end',
 'dparen': 'cmd-lang',
 'echo': 'builtin-cmd',
 'enable': 'builtin-cmd',
 'end()': 'type-method',
 'endsWith()': 'type-method',
 'equal': 'cmd-lang',
 'erase()': 'type-method',
 'error': 'builtin-cmd',
 'eval': 'builtin-cmd',
 'eval()': 'type-method',
 'exec': 'builtin-cmd',
 'exit': 'cmd-lang',
 'exit-codes': 'front-end',
 'export': 'osh-assign',
 'expr-lit': 'expr-lang',
 'expr-splice': 'word-lang',
 'expr-sub': 'word-lang',
 'extend()': 'type-method',
 'extglob': 'mini-lang',
 'false': 'cmd-lang',
 'fat-arrow': 'expr-lang',
 'fg': 'builtin-cmd',
 'find()': 'type-method',
 'flag': 'builtin-cmd',
 'float()': 'builtin-func',
 'for': 'cmd-lang',
 'for-expr-sh': 'cmd-lang',
 'fork': 'builtin-cmd',
 'forkwait': 'builtin-cmd',
 'fromJson()': 'builtin-func',
 'fromJson8()': 'builtin-func',
 'func-call': 'expr-lang',
 'func-def': 'cmd-lang',
 'get()': 'type-method',
 'getopts': 'builtin-cmd',
 'glob()': 'type-method',
 'glob-pat': 'mini-lang',
 'group()': 'type-method',
 'hash': 'builtin-cmd',
 'help': None,
 'here-doc': 'cmd-lang',
 'history': 'builtin-cmd',
 'histsub': 'mini-lang',
 'if': 'cmd-lang',
 'inc()': 'type-method',
 'indexOf()': 'type-method',
 'insert()': 'type-method',
 'int()': 'builtin-func',
 'int-literal': 'expr-lang',
 'is-main': 'builtin-cmd',
 'j8-escape': 'j8',
 'jobs': 'builtin-cmd',
 'join()': 'builtin-func',
 'json': 'builtin-cmd',
 'json-decode-err': 'errors',
 'json-encode-err': 'errors',
 'json-escape': 'j8',
 'json-string': 'j8',
 'json8': 'builtin-cmd',
 'json8-comment': 'j8',
 'json8-decode-err': 'errors',
 'json8-dict': 'j8',
 'json8-encode-err': 'errors',
 'json8-list': 'j8',
 'json8-num': 'j8',
 'json8-str': 'j8',
 'keys()': 'type-method',
 'kill': 'builtin-cmd',
 'lazy-expr-arg': 'cmd-lang',
 'leftMatch()': 'type-method',
 'len()': 'builtin-func',
 'line-continuation': 'front-end',
 'list()': 'builtin-func',
 'list-literal': 'expr-lang',
 'local': 'osh-assign',
 'lower()': 'type-method',
 'mapfile': 'builtin-cmd',
 'match-ops': 'expr-lang',
 'max()': 'builtin-func',
 'maybe()': 'builtin-func',
 'min()': 'builtin-func',
 'module': 'builtin-cmd',
 'multiline-command': 'front-end',
 'named-class': 'expr-lang',
 'no-prefix': 'j8',
 'nullglob': 'option',
 'oils-usage': None,
 'op-format': 'word-lang',
 'op-index': 'word-lang',
 'op-replace': 'word-lang',
 'op-slice': 'word-lang',
 'op-strip': 'word-lang',
 'op-test': 'word-lang',
 'or': 'cmd-lang',
 'ord()': 'builtin-func',
 'osh-chapters': None,
 'osh-string': 'word-lang',
 'osh-usage': None,
 'packle-decode-err': 'errors',
 'packle-encode-err': 'errors',
 'parseArgs()': 'builtin-cmd',
 'parse_at': 'option',
 'parse_brace': 'option',
 'parse_equals': 'option',
 'parse_ignored': 'option',
 'parse_paren': 'option',
 'parse_triple_quote': 'option',
 'parse_ysh_string': 'option',
 'parser': 'builtin-cmd',
 'pipe': 'cmd-lang',
 'pop()': 'type-method',
 'popd': 'builtin-cmd',
 'pp': 'builtin-cmd',
 'printf': 'builtin-cmd',
 'proc-def': 'cmd-lang',
 'process_sub_fail': 'option',
 'promptVal()': 'type-method',
 'push-registers': 'builtin-cmd',
 'pushd': 'builtin-cmd',
 'pwd': 'builtin-cmd',
 'range': 'expr-lang',
 're-capture': 'expr-lang',
 're-compound': 'expr-lang',
 're-flags': 'expr-lang',
 're-literal': 'expr-lang',
 're-multiline': 'expr-lang',
 're-primitive': 'expr-lang',
 're-repeat': 'expr-lang',
 're-splice': 'expr-lang',
 'read': 'builtin-cmd',
 'readarray': 'builtin-cmd',
 'redir-desc': 'cmd-lang',
 'redir-file': 'cmd-lang',
 'regex': 'mini-lang',
 'remove()': 'type-method',
 'renderPrompt()': 'plugin',
 'repeat()': 'builtin-func',
 'replace()': 'type-method',
 'rest': 'builtin-cmd',
 'return': 'cmd-lang',
 'reverse()': 'type-method',
 'round()': 'builtin-func',
 'rune-literal': 'expr-lang',
 'runes()': 'builtin-func',
 'runproc': 'builtin-cmd',
 'search()': 'type-method',
 'semicolon': 'cmd-lang',
 'set': 'builtin-cmd',
 'setValue()': 'type-method',
 'setglobal': 'cmd-lang',
 'setvar': 'cmd-lang',
 'sh-append': 'osh-assign',
 'sh-arith': 'mini-lang',
 'sh-array': 'osh-assign',
 'sh-assign': 'osh-assign',
 'sh-assoc': 'osh-assign',
 'sh-bitwise': 'mini-lang',
 'sh-block': 'cmd-lang',
 'sh-func': 'cmd-lang',
 'sh-logical': 'mini-lang',
 'sh-numbers': 'mini-lang',
 'shSplit()': 'builtin-func',
 'shift': 'osh-assign',
 'shopt': 'builtin-cmd',
 'shvar': 'builtin-cmd',
 'shvar_get()': 'builtin-func',
 'sigpipe_status_ok': 'option',
 'simple-command': 'cmd-lang',
 'simple_word_eval': 'option',
 'source': 'builtin-cmd',
 'split()': 'builtin-func',
 'start()': 'type-method',
 'startsWith()': 'type-method',
 'startup': 'front-end',
 'str()': 'builtin-func',
 'str-template': 'expr-lang',
 'strcmp()': 'builtin-func',
 'strftime()': 'type-method',
 'strict:all': 'option',
 'strict_control_flow': 'option',
 'strict_nameref': 'option',
 'strict_tilde': 'option',
 'strict_word_eval': 'option',
 'subshell': 'cmd-lang',
 'sum()': 'builtin-func',
 'surrogate-pair': 'j8',
 'tagged-str': 'word-lang',
 'test': 'builtin-cmd',
 'thin-arrow': 'expr-lang',
 'tilde-sub': 'word-lang',
 'time': 'cmd-lang',
 'time()': 'type-method',
 'times': 'builtin-cmd',
 'toJson()': 'builtin-func',
 'toJson8()': 'builtin-func',
 'trap': 'builtin-cmd',
 'trim()': 'type-method',
 'trimEnd()': 'type-method',
 'trimStart()': 'type-method',
 'triple-quoted': 'word-lang',
 'true': 'cmd-lang',
 'try': 'builtin-cmd',
 'type': 'builtin-cmd',
 'type()': 'builtin-func',
 'typed-arg': 'cmd-lang',
 'typeset': 'osh-assign',
 'u-prefix': 'j8',
 'umask': 'builtin-cmd',
 'unalias': 'builtin-cmd',
 'unset': 'osh-assign',
 'until': 'cmd-lang',
 'upper()': 'type-method',
 'use': 'builtin-cmd',
 'utf8-decode-err': 'errors',
 'utf8-encode-err': 'errors',
 'values()': 'type-method',
 'var': 'cmd-lang',
 'var-splice': 'word-lang',
 'var-sub': 'word-lang',
 'wait': 'builtin-cmd',
 'while': 'cmd-lang',
 'write': 'builtin-cmd',
 'ysh-arith': 'expr-lang',
 'ysh-bitwise': 'expr-lang',
 'ysh-case': 'cmd-lang',
 'ysh-cd': 'builtin-cmd',
 'ysh-chapters': None,
 'ysh-compare': 'expr-lang',
 'ysh-for': 'cmd-lang',
 'ysh-format': 'word-lang',
 'ysh-if': 'cmd-lang',
 'ysh-index': 'expr-lang',
 'ysh-logical': 'expr-lang',
 'ysh-printf': 'word-lang',
 'ysh-read': 'builtin-cmd',
 'ysh-return': 'cmd-lang',
 'ysh-shopt': 'builtin-cmd',
 'ysh-slice': 'expr-lang',
 'ysh-string': 'word-lang',
 'ysh-ternary': 'expr-lang',
 'ysh-usage': None,
 'ysh-while': 'cmd-lang',
 'ysh:all': 'option',
 'ysh:upgrade': 'option'}


from typing import Dict

def TopicMetadata():
  # type: () -> Dict[str, str]
  return TOPICS
